WeatherAlertSummary

Struct WeatherAlertSummary 

pub struct WeatherAlertSummary {
Show 16 fields pub area_id: Option<String>, pub area_name: Option<String>, pub certainty: Certainty, pub country_code: String, pub description: String, pub details_url: Option<String>, pub effective_time: DateTime<Utc>, pub event_end_time: Option<DateTime<Utc>>, pub event_onset_time: Option<DateTime<Utc>>, pub expire_time: DateTime<Utc>, pub id: String, pub issued_time: DateTime<Utc>, pub responses: Vec<ResponseType>, pub severity: Severity, pub source: String, pub urgency: Option<Urgency>,
}
Detailed information about the weather alert.

Fields

area_id: Option<String>

An official designation of the affected area.

area_name: Option<String>

A human-readable name of the affected area.

certainty: Certainty

How likely the event is to occur.

country_code: String

The ISO code of the reporting country.

description: String

A human-readable description of the event.

details_url: Option<String>

The URL to a page containing detailed information about the event.

effective_time: DateTime<Utc>

The time the event went into effect.

event_end_time: Option<DateTime<Utc>>

The time when the underlying weather event is projected to end.

event_onset_time: Option<DateTime<Utc>>

The time when the underlying weather event is projected to start.

expire_time: DateTime<Utc>

The time when the event expires.

id: String

A unique identifier of the event.

issued_time: DateTime<Utc>

The time that event was issued by the reporting agency.

responses: Vec<ResponseType>

An array of recommended actions from the reporting agency.

severity: Severity

The level of danger to life and property.

source: String

The name of the reporting agency.

urgency: Option<Urgency>

An indication of urgency of action from the reporting agency.